@@ -305,6 +305,8 @@ def get_model_data(model_name=None, lmd=None):
     # ADAPTOR CODE
     amd = {}
 
+    amd['data_source'] = lmd['data_source_name']
+
     if 'tss' in lmd:
         if lmd['tss']['is_timeseries']:
             amd['timeseries'] = {}
@@ -331,7 +333,7 @@ def get_model_data(model_name=None, lmd=None):
             amd[k] = lmd[k]
             if k == 'validation_set_accuracy':
                 if lmd['validation_set_accuracy'] is not None:
-                    amd['accuracy'] = round(lmd['validation_set_accuracy'],3)
+                    amd['accuracy'] = round(lmd['validation_set_accuracy'], 3)
                 else:
                     amd['accuracy'] = None
         else:
@@ -349,7 +351,7 @@ def get_model_data(model_name=None, lmd=None):
             continue
 
         try:
-            icm = _adapt_column(lmd['stats_v2'][col],col)
+            icm = _adapt_column(lmd['stats_v2'][col], col)
         except Exception as e:
             print(e)
             icm = {'column_name': col}
@@ -472,8 +474,11 @@ def get_models():
         try:
             amd = get_model_data(model_name)
             model = {}
-            for k in ['name', 'version', 'is_active', 'predict',
-            'status', 'train_end_at', 'updated_at', 'created_at','current_phase', 'accuracy']:
+
+            KEYS = ['name', 'version', 'is_active', 'predict', 'status', 'train_end_at',
+                    'updated_at', 'created_at','current_phase', 'accuracy', 'data_source']
+
+            for k in KEYS:
                 if k in amd:
                     model[k] = amd[k]
                 else:
