@@ -43,8 +43,4 @@ class SnowflakeDS(SQLDataSource):
         return df, self._make_colmap(df)
 
     def name(self):
-        return '{}: {}/{}'.format(
-            self.__class__.__name__,
-            self.database,
-            self.warehouse
-        )
+        return 'Snowflake - {}'.format(self._query)
